import z from 'zod';
import { ORIGIN_TYPE_PAYPAL, ORIGIN_TYPE_STRIPE } from '../origin/constants';
import { stripePaymentIntentIdParser } from '../stripe/parsers';
import { PAYIN_ORIGIN_TYPES } from './constants';

export const payinOriginTypeParser = z.enum(PAYIN_ORIGIN_TYPES);
export const payinOriginIdParser = stripePaymentIntentIdParser;
export const payinCompositeIdParser = z
  .object({
    provider: payinOriginTypeParser,
    originId: payinOriginIdParser,
  })
  .and(
    z.discriminatedUnion('provider', [
      z.object({
        provider: z.literal(ORIGIN_TYPE_STRIPE),
        originId: stripePaymentIntentIdParser,
      }),
      z.object({
        provider: z.literal(ORIGIN_TYPE_PAYPAL),
        originId: z.literal('paypal'), // TODO
      }),
    ])
  );
